@@ -1,4 +1,4 @@
-# Copyright (c) 2014  Timm Murray
+# Copyright (c) 2015  Timm Murray
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without 
@@ -22,6 +22,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package UAV::Pilot::Commands;
+$UAV::Pilot::Commands::VERSION = '1.1';
 use v5.14;
 use Moose;
 use namespace::autoclean;
@@ -113,6 +114,7 @@ sub load_lib
     my @orig_inc = @INC;
     local @INC = (
         $self->_get_load_module_sub( $dest_namespace, \@orig_inc ),
+        @INC,
     );
 
     my $full_mod_name = $self->MOD_PREFIX
